@@ -7,6 +7,7 @@ import sys; sys.path.append("../../")
 from typing import Union, List
 
 # External
+import osgeo
 from osgeo import gdal, ogr, osr
 import numpy as np
 
@@ -206,6 +207,28 @@ def parse_projection(
     return target_proj.ExportToWkt() if return_wkt else target_proj
 
 
+def _projection_is_latlng(projection: Union[str, int, gdal.Dataset, ogr.DataSource, osr.SpatialReference]) -> bool:
+    """
+    Tests if a projection is in latlng format.
+
+    Parameters
+    ----------
+    projection : Union[str, int, gdal.Dataset, ogr.DataSource, osr.SpatialReference]
+        The projection to test.
+
+    Returns
+    -------
+    bool:
+        **True** if the projection is in latlng format, **False** otherwise.
+    """
+    proj = parse_projection(projection)
+
+    if proj.IsGeographic():
+        return True
+
+    return False
+
+
 def _check_projections_match(
     source1: Union[str, int, gdal.Dataset, ogr.DataSource, osr.SpatialReference],
     source2: Union[str, int, gdal.Dataset, ogr.DataSource, osr.SpatialReference],
@@ -429,13 +452,23 @@ def reproject_bbox(
     if _check_projections_match(src_proj, dst_proj):
         return bbox_ogr
 
-    transformer = osr.CoordinateTransformation(src_proj, dst_proj)
 
     p1 = [x_min, y_min]
     p2 = [x_max, y_min]
     p3 = [x_max, y_max]
     p4 = [x_min, y_max]
 
+    options = osr.CoordinateTransformationOptions()
+    if _projection_is_latlng(src_proj):
+        p1.reverse()
+        p2.reverse()
+        p3.reverse()
+        p4.reverse()
+
+        options.SetAreaOfInterest(-180.0, -90.0, 180.0, 90.0)
+
+    transformer = osr.CoordinateTransformation(src_proj, dst_proj, options)
+
     gdal.PushErrorHandler("CPLQuietErrorHandler")
     try:
         p1t = transformer.TransformPoint(p1[0], p1[1])
@@ -495,7 +528,12 @@ def _reproject_point(
     if _check_projections_match(src_proj, dst_proj):
         return p
 
-    transformer = osr.CoordinateTransformation(src_proj, dst_proj)
+    options = osr.CoordinateTransformationOptions()
+
+    if _projection_is_latlng(dst_proj):
+        options.SetAreaOfInterest(-180.0, -90.0, 180.0, 90.0)
+
+    transformer = osr.CoordinateTransformation(src_proj, dst_proj, options)
 
     gdal.PushErrorHandler("CPLQuietErrorHandler")
     try:
